<?php

/**
 * This class will parse user agent and classify which is come from desktop, mobile, or tablet
 *
 * Class DeviceClassification
 */
class DeviceClassification
{
    /**
     * @var string UA-Parser element used for match: 'device', 'os', 'ua'
     */
    public $matchType;

    /**
     * @var bool
     */
    public $isMobileDevice = false;

    /**
     * @var bool
     */
    public $isMobile = false;

    /**
     * @var bool
     */
    public $isTablet = false;

    /**
     * @var bool
     */
    public $isSpider = false;

    /**
     * @var bool
     */
    public $isComputer = true;

    /**
     * @var array
     */
    private $mobileOSs = ['windows phone 6.5','windows ce','symbian os'];

    /**
     * @var array
     */
    private $mobileBrowsers = [
        'firefox mobile','opera mobile','opera mini','mobile safari','webos','ie mobile','playstation portable',
        'nokia','blackberry','palm','silk','android','maemo','obigo','netfront','avantgo','teleca','semc-browser',
        'bolt','iris','up.browser','symphony','minimo','bunjaloo','jasmine','dolfin','polaris','brew','chrome mobile',
        'uc browser','tizen browser'
    ];

    /**
     * @var array
     */
    private $tablets = ['kindle','ipad','playbook','touchpad','dell streak','galaxy tab','xoom'];

    /**
     * @var array
     */
    private $mobileDevices = [
        'iphone','ipod','ipad','htc','kindle','lumia','amoi','asus','bird','dell','docomo','huawei','i-mate','kyocera',
        'lenovo','lg','kin','motorola','philips','samsung','softbank','palm','hp ','generic feature phone','generic smartphone'
    ];

    /**
     * Get classification result for given Parser result
     *
     * @param \UAParser\Result\Client $parseResult
     * @return $this
     */
    public function classify(\UAParser\Result\Client $parseResult)
    {
        switch (true) {
            case (in_array(strtolower($parseResult->device->family), $this->tablets)):
                $this->matchType      = 'device';
                $this->isTablet       = true;
                $this->isMobileDevice = true;
                $this->isComputer     = false;
                break;

            case (in_array(strtolower($parseResult->device->family), $this->mobileDevices)):
                $this->matchType      = 'device';
                $this->isMobileDevice = true;
                $this->isMobile       = true;
                $this->isComputer     = false;
                break;

            case (strtolower($parseResult->device->family) == 'spider'):
                $this->matchType  = 'device';
                $this->isSpider   = true;
                $this->isComputer = false;
                break;

            case (in_array(strtolower($parseResult->os->family), $this->mobileOSs)):
                $this->matchType      = 'os';
                $this->isMobileDevice = true;
                $this->isMobile       = true;
                $this->isComputer     = false;
                break;

            case (in_array(strtolower($parseResult->ua->family), $this->mobileBrowsers)):
                $this->matchType      = 'ua';
                $this->isMobileDevice = true;
                $this->isMobile       = true;
                $this->isComputer     = false;
                break;
        }

        return $this;
    }
}