<?php
/**
 * Plugin Name: Customer Device Info | Shared By Themes24x7.com
 * Description: Add customer device info into order detail.
 * Author: پرشین اسکریپت
 * Author Email: info@persianscript.ir
 * Version: 1.0.2
 * Stable tag: 1.0.2
 * Tested up to: 4.8
 * Requires at least: 3.0.1
 * Text Domain: woodev
 * Domain Path: /languages/
 */

if (!defined('ABSPATH'))
    exit;

/**
 * Ensure to check if WooCommerce has been activated
 */
$active_plugins = get_option('active_plugins', array());
$active_network_plugins = array_keys(get_site_option('active_sitewide_plugins', array()));
$active_plugins = array_merge($active_plugins, $active_network_plugins);
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', $active_plugins))) {
    function woodev_requirement_notice()
    {
        include_once dirname(__FILE__) . "/templates/requirement-notice.php";
    }

    add_action('admin_notices', 'woodev_requirement_notice');
    return;
}

require_once 'vendor/autoload.php';

if (!class_exists('WoocommerceCustomerDeviceInfo')) {

    /**
     * Class WoocommerceCustomerDeviceInfo
     * This main class for this "WooCommerce Customer Device Info" plugin
     */
    class WoocommerceCustomerDeviceInfo
    {

        public function __construct()
        {
            add_action('init', array($this, 'load_init'));
            add_action('admin_init', array($this, 'load_admin_init'));
        }

        /**
         * add all required wordpress filters, actions, scripts, etc here.
         */
        public function load_init()
        {
            load_plugin_textdomain('woofix', false, dirname(plugin_basename(__FILE__)) . '/languages/');

            add_filter('woocommerce_geolocation_local_database_path', array($this, 'locate_geolocation_database'), 50, 2);
            add_action('woocommerce_checkout_update_order_meta', array($this, 'create_order_adjustment'), 50, 1);
            add_action('woocommerce_admin_order_data_after_shipping_address', array($this, 'adjust_customer_details'), 50, 1);
        }

        /**
         * add all required wordpress filters, actions, scripts, etc here.
         * This is just loaded when admin page visted.
         */
        public function load_admin_init()
        {
            wp_enqueue_script('jquery-ui-tooltip');
            wp_enqueue_script('woodev_js', plugins_url('/assets/js/woodev.js', __FILE__), array('jquery-ui-tooltip'));

            wp_enqueue_style('woodev_css', plugins_url('/assets/css/woodev.css', __FILE__));
        }

        /**
         * Ensure WooCommerce has proper GeoIP database.
         *
         * @param $path
         * @param $version
         * @return string
         */
        public function locate_geolocation_database($path, $version)
        {
            if (!file_exists($path)) {
                $path = dirname(__FILE__) . '/databases/GeoIP' . $version . '.dat';
            }

            return $path;
        }

        /**
         * Add aditional data (country code, client user agent, etc) when an order made
         *
         * @param int $order_id
         */
        public function create_order_adjustment($order_id)
        {
            $gli = WC_Geolocation::geolocate_ip();
            $country_code = $gli['country'];
            update_post_meta($order_id, '_woodev_customer_geolocate_country_code', $country_code);
            if (!empty($_SERVER['HTTP_USER_AGENT'])) {
                update_post_meta($order_id, '_woodev_customer_user_agent', $_SERVER['HTTP_USER_AGENT']);
            }
        }

        /**
         * grab all data and show it on admin order detail page
         *
         * @param WC_Order $order
         */
        public function adjust_customer_details($order)
        {
	        $order_id = $this->getOrderId($order);
            $ua = get_post_meta($order_id, '_woodev_customer_user_agent', true);
            if (!empty($ua)) {
                $parser = UAParser\Parser::create();
                $result = $parser->parse($ua);

                $ua_family = str_replace(' ', '-', strtolower($result->ua->family));
                $ua_name = $result->ua->toString();
                $os_family = str_replace(' ', '-', strtolower($result->os->family));
                $os_name = $result->os->toString();
                $device_family = str_replace(' ', '-', strtolower($result->device->family));
                $device_name = $result->device->toString();

                $classifier = new \DeviceClassification();
                $classification = $classifier->classify($result);
                $country = $this->getCountry($order);

                include_once dirname(__FILE__) . "/templates/device-info.php";
            }
        }

        /**
         * Get country code, name, and ip address
         *
         * @param WC_Order $order
         * @return bool|array
         */
        private function getCountry($order)
        {
	        $order_id = $this->getOrderId($order);
            $ip_address = get_post_meta($order_id, '_customer_ip_address', true);
            $country_code = get_post_meta($order_id, '_woodev_customer_geolocate_country_code', true);

            if (empty($country_code)) {
                return false;
            }

            $countries = WC()->countries->get_countries();
            return array(
                'ip' => $ip_address,
                'code' => $country_code,
                'name' => $countries[$country_code]
            );
        }

	    /**
	     * @param WC_Order $order
	     *
	     * @return mixed
	     */
        private function getOrderId($order)
        {
	        if (method_exists($order,'get_id')) {
		        $order_id = $order->get_id();
	        } else {
		        /** @deprecated keep it for backward compatible */
		        $order_id = $order->id;
	        }
	        return $order_id;
        }
    }
}

new WoocommerceCustomerDeviceInfo();

